from InquirerPy import inquirer
from InquirerPy.base.control import Choice
from InquirerPy.separator import Separator
from ask_football.main import find_columns_and_filters


def main():
    table_headers = inquirer.select(
        message="Select Table Headers: (Use space to select them): ",
        choices=[
                Choice("Year", name="Year"),
                Choice("Hosts", name="Hosts"),
                Choice("Venues and Cities", name="Venues_Cities"),
                Choice("Total Attendance", name="Total_Attendance"),
                Choice("Matches", name="Matches"),
                Choice("Average Attendence", name="Average_Attendance"),
                Choice("Highest Attendance", name="Highest_Attendance"),
                Choice("Highest Attendance Venue",
                       name="Highest_Attendance_Venue"),
                Choice("Highest Attendance Games", name="Highest_Attendance_Games"),],
        multiselect=True,
        transformer=lambda result: f"{len(result)} Table Header{'s' if len(result) > 1 else ''} selected",
    ).execute()
    if table_headers:
        question = inquirer.text(message="Enter your Question:").execute()

    print(find_columns_and_filters(table_headers, question))



import re


def find_columns_and_filters(table_headers, question):
    relevant_columns = []
    filters = {}

    column_patterns = {
        "Year": r"\byear\b|\byears\b",
        "Host": r"\bhost\b|\bhosts\b",
        "Venues_Cities": r"\bvenue\b|\bvenues\b|\bcity\b|\bcities\b",
        "Total_Attendance": r"\btotal attendance\b",
        "Matches": r"\bmatch\b|\bmatches\b",
        "Average_Attendance": r"\baverage attendance\b",
        "Highest_Attendance_Number": r"\bhighest attendance\b",
        "Highest_Attendance_Venue": r"\bvenue\b",
        "Highest_Attendance_Games": r"\bgame\b|\bgames\b",
        "Winner": r"\bwinner\b|\bwinners\b"
        # Ref: https://github.com/scrapinghub/dateparser/blob/master/dateparser/data/date_translation_data/en.py
    }

    for header in table_headers:
        pattern = column_patterns.get(header)
        if pattern and re.search(pattern, question, re.IGNORECASE):
            relevant_columns.append(header)

    year_match = re.search(r"\b\d{4}\b", question)
    if year_match:
        filters["Year"] = year_match.group()

    return relevant_columns, filters
